PostgresqlMigrationResult class

Result of applying a PostgreSQL migration plan.

Constructors

PostgresqlMigrationResult({required PostgresqlMigrationPlan plan, required bool applied})
Creates a PostgreSQL migration result.
const

Properties

applied bool
Whether the migration was applied.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
plan PostgresqlMigrationPlan
Executed or proposed migration plan.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited