PostgresqlRollbackResult class

Result of rolling back PostgreSQL migration state.

Constructors

PostgresqlRollbackResult({required String targetMigrationName, required bool rolledBack, required int statementCount, required List<String> warnings})
Creates a rollback result.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
rolledBack bool
Whether rollback statements were applied.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statementCount int
Number of executed rollback statements.
finalinherited
targetMigrationName String
Name of the migration that was rolled back to.
finalinherited
warnings List<String>
Warnings raised for the rollback plan.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited