PostgresqlSchemaIntrospector class

Introspects live PostgreSQL schemas into SchemaDocument values.

Constructors

PostgresqlSchemaIntrospector()
Creates a PostgreSQL schema introspector.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

introspect(SessionExecutor executor, {String schemaName = 'public'}) Future<SchemaDocument>
Reads schema metadata from executor.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited