PostgresqlCliSession class
Open PostgreSQL session and its close hook.
Constructors
-
PostgresqlCliSession({required SessionExecutor executor, required Future<
void> close()}) -
Creates a CLI session wrapper.
const
Properties
-
close
→ Future<
void> Function() -
Closes the underlying connection or pool.
final
- executor → SessionExecutor
-
Session executor used by the migration commands.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited