PostgresqlMigrationPlanner class
Computes PostgreSQL migration plans from schema diffs or live databases.
Constructors
- PostgresqlMigrationPlanner({PostgresqlSchemaApplier schemaApplier = const PostgresqlSchemaApplier(), PostgresqlSchemaIntrospector schemaIntrospector = const PostgresqlSchemaIntrospector()})
-
Creates a PostgreSQL migration planner.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schemaApplier → PostgresqlSchemaApplier
-
Helper used to render PostgreSQL DDL statements.
final
- schemaIntrospector → PostgresqlSchemaIntrospector
-
Helper used to introspect live PostgreSQL schemas.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
plan(
{required SchemaDocument from, required SchemaDocument to}) → PostgresqlMigrationPlan - Builds a plan from two schema snapshots.
-
planFromDatabase(
{required SessionExecutor executor, required SchemaDocument to}) → Future< PostgresqlMigrationPlan> - Builds a plan by introspecting the live database first.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited